@@ -21,51 +21,7 @@
 #include "imagebase_p.h"
 #include <qdeclarative.h>
 
-class ImageBorder : public QObject
-{
-    Q_OBJECT
-
-    Q_PROPERTY(int left READ left WRITE setLeft RESET resetLeft NOTIFY leftChanged)
-    Q_PROPERTY(int right READ right WRITE setRight RESET resetRight NOTIFY rightChanged)
-    Q_PROPERTY(int top READ top WRITE setTop RESET resetTop NOTIFY topChanged)
-    Q_PROPERTY(int bottom READ bottom WRITE setBottom NOTIFY resetBottom NOTIFY bottomChanged)
-
-public:
-    explicit ImageBorder(ImageBase *parent = 0);
-    ~ImageBorder();
-
-    int left() const;
-    void setLeft(int left);
-    void resetLeft();
-
-    int right() const;
-    void setRight(int right);
-    void resetRight();
-
-    int top() const;
-    void setTop(int top);
-    void resetTop();
-
-    int bottom() const;
-    void setBottom(int bottom);
-    void resetBottom();
-
-signals:
-    void leftChanged();
-    void rightChanged();
-    void topChanged();
-    void bottomChanged();
-
-private:
-    int m_left;
-    int m_right;
-    int m_top;
-    int m_bottom;
-
-    Q_DISABLE_COPY(ImageBorder)
-};
-
-class ImageLoader;
+class ImageBorder;
 class BorderImagePrivate;
 
 class BorderImage : public ImageBase
@@ -75,6 +31,7 @@ class BorderImage : public ImageBase
     Q_PRIVATE_PROPERTY(BorderImage::d_func(), ImageBorder* border READ border CONSTANT FINAL)
     Q_PROPERTY(TileMode horizontalTileMode READ horizontalTileMode WRITE setHorizontalTileMode NOTIFY horizontalTileModeChanged)
     Q_PROPERTY(TileMode verticalTileMode READ verticalTileMode WRITE setVerticalTileMode NOTIFY verticalTileModeChanged)
+    Q_PROPERTY(QSize sourceSize READ sourceSize NOTIFY sourceSizeChanged) // read-only
 
     Q_ENUMS(TileMode)
 
@@ -97,21 +54,19 @@ public:
 signals:
     void horizontalTileModeChanged();
     void verticalTileModeChanged();
+    void sourceSizeChanged();
 
 protected:
     BorderImage(BorderImagePrivate &dd, QWidget *parent = 0);
+    
+    virtual void paintEvent(QPaintEvent *);
 
     Q_DECLARE_PRIVATE(BorderImage)
 
-    Q_PRIVATE_SLOT(d_func(), void _q_onLoaderFinished(ImageLoader*))
-    Q_PRIVATE_SLOT(d_func(), void _q_onLoaderCanceled(ImageLoader*))
-    Q_PRIVATE_SLOT(d_func(), void _q_onLoaderProgressChanged(qreal))
-
 private:
     Q_DISABLE_COPY(BorderImage)
 };
 
 QML_DECLARE_TYPE(BorderImage)
-QML_DECLARE_TYPE(ImageBorder)
 
 #endif // BORDERIMAGE_P_H
