@@ -23,13 +23,17 @@
 #include "borderimage_p.h"
 #include "button_p.h"
 #include "buttonrow_p.h"
+#include "buttonstyle_p.h"
 #include "checkbox_p.h"
+#include "checkboxstyle_p.h"
 #include "column_p.h"
 #include "dateselector_p.h"
 #include "dialog_p.h"
 #include "doublespinbox_p.h"
 #include "editbar_p.h"
+#include "filesystemmodel_p.h"
 #include "flickable_p.h"
+#include "flickablestyle_p.h"
 #include "flow_p.h"
 #include "grid_p.h"
 #include "headerview_p.h"
@@ -39,9 +43,11 @@
 #include "informationbox_p.h"
 #include "item_p.h"
 #include "itemaction_p.h"
+#include "keyevent_p.h"
 #include "keys_p.h"
 #include "label_p.h"
-//#include "listelement_p.h"
+#include "labelstyle_p.h"
+#include "listelement_p.h"
 #include "listitem_p.h"
 #include "listitemborderimage_p.h"
 #include "listitemimage_p.h"
@@ -53,15 +59,19 @@
 #include "listmodel_p.h"
 #include "listselector_p.h"
 #include "listview_p.h"
+#include "listviewstyle_p.h"
 #include "loader_p.h"
 #include "menu_p.h"
+#include "menustyle_p.h"
 #include "modelindex_p.h"
 #include "mousearea_p.h"
+#include "mouseevent_p.h"
 #include "multilistselector_p.h"
 #include "page_p.h"
 #include "pagestack_p.h"
 #include "platformstyle_p.h"
 #include "progressbar_p.h"
+#include "progressbarstyle_p.h"
 #include "qdeclarativebind_p.h"
 #include "qdeclarativeconnections_p.h"
 #include "qdeclarativetimer_p.h"
@@ -72,17 +82,29 @@
 #include "screen_p.h"
 #include "separator_p.h"
 #include "slider_p.h"
+#include "sliderstyle_p.h"
 #include "spinbox_p.h"
+#include "spinboxstyle_p.h"
 #include "sortfilterproxymodel_p.h"
 #include "tabbar_p.h"
+#include "tabbarstyle_p.h"
 #include "tabgroup_p.h"
 #include "tableview_p.h"
+#include "tableviewstyle_p.h"
 #include "text_p.h"
+#include "textbrowser_p.h"
 #include "textedit_p.h"
+#include "texteditstyle_p.h"
 #include "textfield_p.h"
+#include "textfieldstyle_p.h"
+#include "textstyle_p.h"
 #include "timeselector_p.h"
 #include "toolbar_p.h"
+#include "toolbarstyle_p.h"
 #include "toolbutton_p.h"
+#include "toolbuttonstyle_p.h"
+#include "treeview_p.h"
+#include "treeviewstyle_p.h"
 #include "valuebutton_p.h"
 #include "valueselector_p.h"
 #include "window_p.h"
@@ -122,6 +144,7 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterUncreatableType<KeyEvent>(uri, 1, 0, "KeyEvent", "");
     qmlRegisterUncreatableType<MouseDrag>(uri, 1, 0, "Drag", "");
     qmlRegisterUncreatableType<PageStack>(uri, 1, 0, "PageStack", "");
+    qmlRegisterUncreatableType<Style>(uri, 1, 0, "StyleBase", "");
     qmlRegisterUncreatableType<QWidget>(uri, 1, 0, "Widget", "");
     qmlRegisterUncreatableType<QAbstractButton>(uri, 1, 0, "AbstractButton", "");
     qmlRegisterUncreatableType<QHeaderView>(uri, 1, 0, "QHeaderView", "");
@@ -129,15 +152,20 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterType<Action>(uri, 1, 0, "Action");
     qmlRegisterType<ActionGroup>(uri, 1, 0, "ActionGroup");
     qmlRegisterType<BorderImage>(uri, 1, 0, "BorderImage");
+    qmlRegisterType<BoxStyle>(uri, 1, 0, "Style");
     qmlRegisterType<Button>(uri, 1, 0, "Button");
     qmlRegisterType<ButtonRow>(uri, 1, 0, "ButtonRow");
+    qmlRegisterType<ButtonStyle>(uri, 1, 0, "ButtonStyle");
     qmlRegisterType<CheckBox>(uri, 1, 0, "CheckBox");
+    qmlRegisterType<CheckBoxStyle>(uri, 1, 0, "CheckBoxStyle");
     qmlRegisterType<Column>(uri, 1, 0, "Column");
     qmlRegisterType<DateSelector>(uri, 1, 0, "DateSelector");
     qmlRegisterType<Dialog>(uri, 1, 0, "Dialog");
     qmlRegisterType<DoubleSpinBox>(uri, 1, 0, "DoubleSpinBox");
     qmlRegisterType<EditBar>(uri, 1, 0, "EditBar");
+    qmlRegisterType<FileSystemModel>(uri, 1, 0, "FileSystemModel");
     qmlRegisterType<Flickable>(uri, 1, 0, "Flickable");
+    qmlRegisterType<FlickableStyle>(uri, 1, 0, "FlickableStyle");
     qmlRegisterType<Flow>(uri, 1, 0, "Flow");
     qmlRegisterType<Gradient>(uri, 1, 0, "Gradient");
     qmlRegisterType<GradientStop>(uri, 1, 0, "GradientStop");
@@ -149,6 +177,8 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterType<Item>(uri, 1, 0, "Item");
     qmlRegisterType<ItemAction>(uri, 1, 0, "ItemAction");
     qmlRegisterType<Label>(uri, 1, 0, "Label");
+    qmlRegisterType<LabelStyle>(uri, 1, 0, "LabelStyle");
+    qmlRegisterType<ListElement>(uri, 1, 0, "ListElement");
     qmlRegisterType<ListItem>(uri, 1, 0, "ListItem");
     qmlRegisterType<ListItemBorderImage>(uri, 1, 0, "ListItemBorderImage");
     qmlRegisterType<ListItemImage>(uri, 1, 0, "ListItemImage");
@@ -160,12 +190,15 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterType<ListModel>(uri, 1, 0, "ListModel");
     qmlRegisterType<ListSelector>(uri, 1, 0, "ListSelector");
     qmlRegisterType<ListView>(uri, 1, 0, "ListView");
+    qmlRegisterType<ListViewStyle>(uri, 1, 0, "ListViewStyle");
     qmlRegisterType<Loader>(uri, 1, 0, "Loader");
     qmlRegisterType<Menu>(uri, 1, 0, "Menu");
+    qmlRegisterType<MenuStyle>(uri, 1, 0, "MenuStyle");
     qmlRegisterType<MouseArea>(uri, 1, 0, "MouseArea");
     qmlRegisterType<MultiListSelector>(uri, 1, 0, "MultiListSelector");
     qmlRegisterType<Page>(uri, 1, 0, "Page");
     qmlRegisterType<ProgressBar>(uri, 1, 0, "ProgressBar");
+    qmlRegisterType<ProgressBarStyle>(uri, 1, 0, "ProgressBarStyle");
     qmlRegisterType<QDeclarativeBind>(uri, 1, 0, "Binding");
     qmlRegisterType<QDeclarativeComponent>(uri, 1, 0, "Component");
     qmlRegisterType<QDeclarativeTimer>(uri, 1, 0, "Timer");
@@ -179,18 +212,30 @@ void Plugin::registerTypes(const char *uri) {
     qmlRegisterType<Row>(uri, 1, 0, "Row");
     qmlRegisterType<Separator>(uri, 1, 0, "MenuSeparator");
     qmlRegisterType<Slider>(uri, 1, 0, "Slider");
+    qmlRegisterType<SliderStyle>(uri, 1, 0, "SliderStyle");
     qmlRegisterType<SortFilterProxyModel>(uri, 1, 0, "SortFilterProxyModel");
     qmlRegisterType<SpinBox>(uri, 1, 0, "SpinBox");
+    qmlRegisterType<SpinBoxStyle>(uri, 1, 0, "SpinBoxStyle");
     qmlRegisterType<TabBar>(uri, 1, 0, "TabBar");
+    qmlRegisterType<TabBarStyle>(uri, 1, 0, "TabBarStyle");
     qmlRegisterType<TabButton>(uri, 1, 0, "TabButton");
     qmlRegisterType<TabGroup>(uri, 1, 0, "TabGroup");
     qmlRegisterType<TableView>(uri, 1, 0, "TableView");
+    qmlRegisterType<TableViewStyle>(uri, 1, 0, "TableViewStyle");
     qmlRegisterType<Text>(uri, 1, 0, "Text");
+    qmlRegisterType<TextBrowser>(uri, 1, 0, "TextBrowser");
     qmlRegisterType<TextEdit>(uri, 1, 0, "TextEdit");
+    qmlRegisterType<TextEditStyle>(uri, 1, 0, "TextEditStyle");
     qmlRegisterType<TextField>(uri, 1, 0, "TextField");
+    qmlRegisterType<TextFieldStyle>(uri, 1, 0, "TextFieldStyle");
+    qmlRegisterType<TextStyle>(uri, 1, 0, "TextStyle");
     qmlRegisterType<TimeSelector>(uri, 1, 0, "TimeSelector");
     qmlRegisterType<ToolBar>(uri, 1, 0, "ToolBar");
+    qmlRegisterType<ToolBarStyle>(uri, 1, 0, "ToolBarStyle");
     qmlRegisterType<ToolButton>(uri, 1, 0, "ToolButton");
+    qmlRegisterType<ToolButtonStyle>(uri, 1, 0, "ToolButtonStyle");
+    qmlRegisterType<TreeView>(uri, 1, 0, "TreeView");
+    qmlRegisterType<TreeViewStyle>(uri, 1, 0, "TreeViewStyle");
     qmlRegisterType<ValueButton>(uri, 1, 0, "ValueButton");
     qmlRegisterType<ValueSelector>(uri, 1, 0, "ValueSelector");
     qmlRegisterType<Window>(uri, 1, 0, "Window");
