@@ -56,6 +56,7 @@ class TextField : public QLineEdit, public QDeclarativeParserStatus
     Q_PRIVATE_PROPERTY(TextField::d_func(), bool visible READ qmlVisible WRITE setQmlVisible NOTIFY visibleChanged)
     Q_PRIVATE_PROPERTY(TextField::d_func(), bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
     Q_PRIVATE_PROPERTY(TextField::d_func(), QValidator* validator READ validator WRITE setValidator)
+    Q_PRIVATE_PROPERTY(TextField::d_func(), Style* style READ style WRITE setStyle RESET resetStyle)
 
     Q_INTERFACES(QDeclarativeParserStatus)
 
@@ -117,6 +118,8 @@ protected:
     QScopedPointer<TextFieldPrivate> d_ptr;
 
     Q_DECLARE_PRIVATE(TextField)
+    
+    Q_PRIVATE_SLOT(d_func(), void _q_onStyleChanged())
 
 private:
     Q_DISABLE_COPY(TextField)
