@@ -52,6 +52,7 @@ class ValueButton : public QMaemo5ValueButton, public QDeclarativeParserStatus
     Q_PRIVATE_PROPERTY(ValueButton::d_func(), QDeclarativeListProperty<QObject> actions READ actions)
     Q_PRIVATE_PROPERTY(ValueButton::d_func(), bool visible READ qmlVisible WRITE setQmlVisible NOTIFY visibleChanged)
     Q_PRIVATE_PROPERTY(ValueButton::d_func(), bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
+    Q_PRIVATE_PROPERTY(ValueButton::d_func(), Style* style READ style WRITE setStyle RESET resetStyle)
 
     Q_INTERFACES(QDeclarativeParserStatus)
 
@@ -114,6 +115,8 @@ protected:
     QScopedPointer<ValueButtonPrivate> d_ptr;
 
     Q_DECLARE_PRIVATE(ValueButton)
+    
+    Q_PRIVATE_SLOT(d_func(), void _q_onStyleChanged())
 
 private:
     Q_DISABLE_COPY(ValueButton)
