@@ -55,6 +55,7 @@ class Window : public QMainWindow, public QDeclarativeParserStatus
     Q_PRIVATE_PROPERTY(Window::d_func(), QDeclarativeListProperty<QObject> tools READ tools)
     Q_PRIVATE_PROPERTY(Window::d_func(), QDeclarativeListProperty<QObject> actions READ actions)
     Q_PRIVATE_PROPERTY(Window::d_func(), bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
+    Q_PRIVATE_PROPERTY(Window::d_func(), Style* style READ style WRITE setStyle RESET resetStyle)
 
     Q_INTERFACES(QDeclarativeParserStatus)
 
@@ -123,6 +124,8 @@ protected:
     QScopedPointer<WindowPrivate> d_ptr;
 
     Q_DECLARE_PRIVATE(Window)
+    
+    Q_PRIVATE_SLOT(d_func(), void _q_onStyleChanged())
 
 private:
     Q_DISABLE_COPY(Window)
