@@ -17,6 +17,7 @@
 
 #include "dbusmessage_p.h"
 #include "dbusutils_p.h"
+#include "qdbusutil_p.h"
 #include <QDBusInterface>
 #include <QDBusConnection>
 #include <QDBusMessage>
@@ -330,6 +331,10 @@ QVariant DBusMessage::reply() const {
     return d->reply;
 }
 
+QString DBusMessage::replyString() const {
+    return QDBusUtil::argumentToString(this->reply());
+}
+
 void DBusMessage::send() {
     Q_D(DBusMessage);
 
